@@ -883,7 +883,7 @@ class CbsClient(AbstractClient):
     def ModifyDiskExtraPerformance(self, request):
         """本接口（ModifyDiskExtraPerformance）用于调整云硬盘额外的性能。
 
-        * 目前仅支持极速型SSD云硬盘（CLOUD_TSSD）和高性能SSD云硬盘(CLOUD_HSSD)。
+        * 目前仅支持增强型SSD云硬盘(CLOUD_HSSD)和极速型SSD云硬盘（CLOUD_TSSD）。
 
         :param request: Request instance for ModifyDiskExtraPerformance.
         :type request: :class:`tencentcloud.cbs.v20170312.models.ModifyDiskExtraPerformanceRequest`
